#!/usr/bin/env python
__author__ = "Jordan Bradley"
__copyright__ = "Copyright 2024, International Cybernetics"
__credits__ = [""]
__license__ = ""
__version__ = "1.01.01"
__maintainer__ = "Jordan Bradley"
__email__ = "jbradley@internationalcybernetics.com"
__status__ = "Released"
__network_repository__ = "//icc-proc-vsf003/shares$/Services/Connect/ProcessingPlayground/icc_repo/pythonprojects"
